@@ -406,17 +406,17 @@ class Database(object):
 	def load(self, 
 		# the subpath of the content (! param number 1).
 		path=None, 
-		# specify default to create when non existant.
+		# the default data, specify to call self.check() automatically on the data object.
 		default=None,
 	):
-		if not self.activated: return r3sponse.error(f"Encrypted database {self.path} is not activated yet, call database.activate() first.")
+		if not self.activated: return r3sponse.error(f"Encrypted database [{self.path}] is not activated yet, call database.activate() first.")
 		response = r3sponse.check_parameters({
 			"path:str":path,})
 		if not response.success: return response
 		content = self.DataObject(path=f"{self.path}/{path}", default=default, aes=self.aes)
 		response = content.load()
 		if not response.success: return response
-		return r3sponse.success(f"Successfully loaded content {path}.", {
+		return r3sponse.success(f"Successfully loaded content [{path}].", {
 			"content":content,
 		})
 	def save(self, 
@@ -495,9 +495,8 @@ class Database(object):
 		# load & decrypt.
 		def load(self):
 			try:
-				content = Files.load(self.path)
+				format, content = Files.load(str(self.path)).split(" ")
 			except Exception as e: return r3sponse.error(f"Failed to load content {self.path}, {e}.")
-			format, content = content.split(" ")
 			response = self.aes.decrypt(content.encode())
 			if not response.success: return response
 			decrypted = response.decrypted.decode()
