@@ -5,21 +5,25 @@
 import os, sys, ast, json, glob, platform, random
 import syst3m, cl1
 from r3sponse import r3sponse
-from fil3s import Files, Formats
+from fil3s import *
 
 # source.
 ALIAS = "encrypti0n"
 SOURCE_NAME = "encrypti0n"
-SOURCE_PATH = syst3m.defaults.get_source_path(__file__, back=3)
-BASE = syst3m.defaults.get_source_path(SOURCE_PATH)
-OS = syst3m.defaults.check_operating_system(supported=["linux", "osx"])
-syst3m.defaults.check_alias(alias=ALIAS, executable=f"{SOURCE_PATH}/", sudo=True)
+SOURCE_PATH = syst3m.defaults.source_path(__file__, back=3)
+BASE = syst3m.defaults.source_path(SOURCE_PATH)
+OS = syst3m.defaults.operating_system(supported=["linux", "macos"])
+syst3m.defaults.alias(alias=ALIAS, executable=f"{SOURCE_PATH}/", sudo=True)
+
+# version.
+try: version = Files.load(f"{SOURCE_PATH}/.version")
+except: version = "unkown"
 
 # file settings.
 ADMINISTRATOR = "administrator"
 OWNER = os.environ.get("USER")
 GROUP = "root"
-if OS in ["osx"]: GROUP = "wheel"
+if OS in ["macos"]: GROUP = "wheel"
 SUDO = True
 ADMIN_PERMISSION = 700
 READ_PERMISSION = 750
